<%
'THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT 
'WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED, 
'INCLUDING BUT NOT LIMITED TO THE IMPLIED WARRANTIES 
'OF MERCHANTABILITY AND/OR FITNESS FOR A PARTICULAR 
'PURPOSE

'------------------------------------------------------------------------------
'
' NAME: Folder.inc
'
' FILE DESCRIPTION: Contains the renderer functions
'
' Copyright (c) CdoLive 1999. All rights reserved.
'               Http://www.cdolive.com
'               Mailto:samples@cdolive.com
'
' Portions:
' Copyright (c) Microsoft Corporation 1993-1997. All rights reserved.
'
'------------------------------------------------------------------------------

'==============================
' GetRenderer
'
' Get render application
'==============================

Function GetRenderer(nType)

	' Declare variables
	Dim objRenderApp
	Dim objRenderer

	' Initialize variables
	Set objRenderApp = Nothing
	Set GetRenderer = Nothing

	' Get render application object
	Set objRenderApp = Application("RenderApplication")

	' Check if render application is not set
	If Not objRenderApp Is Nothing Then

		' Create renderer
		Set objRenderer = objRenderApp.CreateRenderer(nType)
		If IsEmpty(Session("hImp")) Then
			Session("hImp") = objRenderApp.ImpID
		End If
	End If

	' Set return value
	Set GetRenderer = objRenderer
End Function

'==============================
' GetFolderRenderer
'
' Create folder renderer
'==============================

Function GetFolderRenderer(objDefault)

	' Declare variables
	Dim objRenderApp
	Dim objRenderer
	Dim objMessages
	Dim objFormat
	Dim objPatterns
	Dim objView
	Dim objColumns

	' Initialize variables
	Set GetFolderRenderer = Nothing
	Set objRenderApp = Nothing
	Set objRenderer = Nothing
	Set objMessages = Nothing
	Set objFormat = Nothing
	Set objPatterns = Nothing
	Set objView = Nothing
	Set objColumns = Nothing

	' Get render application object
	Set objRenderApp = Application("RenderApplication")

	' Create container renderer and set datasource
	Set objRenderer = objRenderApp.CreateRenderer(3)
	objRenderer.DataSource = Session("MessagesCollection")

	' Sort messages descending by submitting date
	Set objMessages = objRenderer.DataSource
	objMessages.Sort 2

	Set objFormat = objRenderer.Formats.Add(CdoPR_MESSAGE_DELIVERY_TIME)
	Set objPatterns = objFormat.Patterns
	objPatterns.Add "*", "<font face='Arial, Helvetica, sans-serif' size='2'>%value%</font>"
	Set objFormat = objRenderer.Formats.Add(CdoPR_SUBJECT)
	Set objPatterns = objFormat.Patterns
	objPatterns.Add "*","<font face='Arial, Helvetica, sans-serif' size='2'>%value%</font>"
	Set objFormat = objRenderer.Formats.Add(CdoPR_MESSAGE_CLASS)
	Set objPatterns = objFormat.Patterns
	objPatterns.Add "IPM*", "<img src='tag.gif'>"

	' Create view and set columns
	Set objView = objRenderer.Views.Add("DefaultView")
	Set objColumns = objView.Columns

	' Add columns to view
	' Note: do not remove the space character otherwise the heading row
	' will end up in an undefined state
	objColumns.Add " ", CdoPR_MESSAGE_CLASS, 1, 8, 1
	objColumns.Add " ", CdoPR_MESSAGE_DELIVERY_TIME, 18, 0, 2
	objColumns.Add " ", CdoPR_SUBJECT, 50, 32, 3
	objRenderer.CurrentView = "DefaultView"

	' Set url link
	objRenderer.LinkPattern = "<a style='text-decoration:none' href='read.asp?index=%rowid%&obj=%obj%' onMouseOver='message(""Click to display headline"");return true;'" & ">%value%</a>"

	' Set maximum displayed rows
	objRenderer.RowsPerPage = APP_ITEM_COUNT

	' Hide heading row
	' Note: do not remove this lines otherwise the heading row
	' will become visible with the default color
	objRenderer.HeadingRowPrefix = "<tr valign='top'>"
	objRenderer.HeadingRowSuffix = "</tr>"

	' Set row and cell rendering styles
	' Note: do not remove this lines otherwise each row
	' will be displayed with the default backround color
	objRenderer.RowPrefix = "<tr valign='middle' face='Arial, Helvetica, sans-serif' size='1'>"
	objRenderer.RowSuffix = "</tr>"

	' Set return value
	Set GetFolderRenderer = objRenderer
End Function

'==============================
' GetMessageRenderer
'
' Create message renderer
'==============================

Function GetMessageRenderer()

	' Declare variables
	Dim objRenderer

	' Initialize variables
	Set GetMessageRenderer = Nothing
	Set objRenderer = Nothing

	If IsEmpty(Session("MessageRenderer")) Then
		Set objRenderer = GetRenderer(2)
		objRenderer.LinkPattern = "read.asp?obj=%obj%"
		Set Session("MessageRenderer") = objRenderer
	Else

		' Get message renderer
		Set objRenderer = Session("MessageRenderer")
	End If

	' Set return value
	Set GetMessageRenderer = objRenderer
End Function

'==============================
' GetObjectRenderer
'
' Create object renderer
'==============================

Function GetObjectRenderer()

	' Declare variables
	Dim objRenderer

	' Initialize variables
	Set GetObjectRenderer = Nothing

	' Get object renderer
	If IsEmpty(Session("ObjectRenderer")) Then

		' Create object render
		Set objRenderer = GetRenderer(2)
		Set Session("ObjectRenderer") = objRenderer
	Else

		' Set object renderer
		Set objRenderer = Session("ObjectRenderer")
	End If

	' Set return value
	Set GetObjectRenderer = objRenderer
End Function

'==============================
' SetNews
'
' Initialize application
'==============================

Function SetNews(bstrFolderID)

	' Initialize variables
	SetNews = False

	' Get MAPI session object
	On Error Resume Next
	Set objCDOAnonSession = Application("CDOAnonSession")

	' Check if folder ID is not empty
	If Not bstrFolderID = "" Then

		' Get folder
		On Error Resume Next
		Set objFolder = objCDOAnonSession.GetFolder(bstrFolderID, NULL)

		' Check for possible errors
		If Err.Number <> 0 then

			' Try again to get folder
			Set objFolder = objCDOAnonSession.GetFolder(bstrFolderID, NULL)

			' Again check for possible errors
			If Err.Number <> 0 Then

				' Display error message
				Response.Write(bstrFolderID & "<br>")
				Response.Write(Err.Number & ": " & Err.Description & "<br>")
				ReportError "Folder.inc: Cannot open requested folder."
			End If
		End If

		' Set messages collection and folder ID
		Set Session("MessagesCollection") = objFolder.Messages

		' Get container renderer
		Set objRFRenderer = GetFolderRenderer(Session("MessagesCollection"))

		' Set return value
		SetNews = True
	End If
End Function


'=======================
' CheckIndex
'
' Check index returned and assign to session
'=======================

Public Sub CheckIndex

	' Declare variables
	Dim strIndex
	Dim intIndex

	' Get index
	strIndex = Request.QueryString("index")

	' Check if index is not empty
	If Len(strIndex) > 0 Then

		' Convert string to integer
		intIndex = CInt(strIndex)

		' Set current index
		Session("CurrentIndex") = intIndex
	End If
End Sub

'=======================
' ReportError
'
' Error handling function
'=======================

Public Function ReportError(bstrErr)
	DisplayError bstrErr, False
End Function

'=======================
' DisplayError
'
' Error display function
'
' if fClose parameter is true, the current window
' is closed, otherwise the function will navigate
' to the previous location in the history
' Displays CDO error descriptions if debug parameter is set to one
'=======================

Public Function DisplayError(bstrErr, fClose)

	' Declare variables
	Dim bstrMessage
	Dim objRenderer

	' Initialize variables
	Set objRenderer = Nothing
	bstrMessage = bstrErr

	Set objRenderApp = Application("RenderApplication")
	If objRenderApp.ConfigParameter("Debug") = 1 Then
		If Err.Number <> 0 Then
			bstrMessage = bstrMessage & vbCRLF & hex(Err.Number) & ": " & Err.Description
			bstrMessage = bstrMessage & vbCRLF & Request.ServerVariables("SCRIPT_NAME")
		End If
	End If

	' Display error message
	Response.Write( bstrMessage)
	Response.End
End Function
%>