<%
'THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT 
'WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED, 
'INCLUDING BUT NOT LIMITED TO THE IMPLIED WARRANTIES 
'OF MERCHANTABILITY AND/OR FITNESS FOR A PARTICULAR 
'PURPOSE

'------------------------------------------------------------------------------
'
' NAME: Logon.inc
'
' FILE DESCRIPTION: Contains methods to create and check an anonymous CDO session
'
' Copyright (c) CdoLive 1999. All rights reserved.
'               Http://www.cdolive.com
'               Mailto:samples@cdolive.com
'
' Portions:
' Copyright (c) Microsoft Corporation 1993-1997. All rights reserved.
'
'------------------------------------------------------------------------------

'==============================
' CheckCDOAnonSession
'
' Checks that an anonymous MAPI session exists in the Application object, or create if necessary
'==============================

Public Function CheckCDOAnonSession

	' Declare variables
	Dim objSession

	' Initialize variables
	CheckCDOAnonSession = False
	Set objSession = Nothing

	' Set anonymous session
	On Error Resume Next
	Set objSession = Application("CDOAnonSession")

	' Check if session is not set
	If objSession Is Nothing Then

		' Try to logon again
		NoAnonSession

		' Set session
		Set objSession = Application("CDOAnonSession")
	End If

	' Check if session is set
	If Not objSession is Nothing Then

		' Set return value
		CheckCDOAnonSession = True
	End If
End Function

'==============================
' NoAnonSession
'
' Get config, create dynamic profile for anonymous logon and create a CDO session
'==============================

Sub NoAnonSession

	' Declare variables
	Dim objRenderApp
	Dim objSession
	Dim objStores
	Dim bstrEnterprise
	Dim bstrSite
	Dim bstrServer
	Dim bstrProfileInfo
	Dim blnAddressList
	Dim intCounter
	Dim intTimeout

	' Initialize variables
	Set objRenderApp = Nothing
	Set objSession = Nothing
	Set objStores = Nothing
	bstrEnterprise = ""
	bstrSite = ""
	bstrServer = ""
	bstrProfileInfo = ""
	blnAddressList = False
	intCounter = 1
	intTimeout = 0

	' Set render application
	On Error Resume Next
	Set objRenderApp = Application("RenderApplication")

	' Check if render application is set
	If Not objRenderApp Is Nothing Then

		' Pull Exchange config out of the registry
		Err.Clear
		On Error Resume Next
		objRenderApp.LoadConfiguration 1, "HKEY_LOCAL_MACHINE\System\CurrentControlSet\Services\MSExchangeWeb\Parameters"

		' Check for possible errors
		If Err.Number = 0 Then
			bstrEnterprise = objRenderApp.ConfigParameter("Enterprise")
			bstrSite = objRenderApp.ConfigParameter("Site")
			bstrServer = objRenderApp.ConfigParameter("Server")

			' Construct CDO profile
			bstrProfileInfo = "/o=" + bstrEnterprise + "/ou=" + bstrSite + "/cn=Configuration/cn=Servers/cn=" + bstrServer + vbLF + "anon" + vbLF + "anon"
		Else

			' Display error message
			Call DebugAssert("RenderingApplication.LoadConfiguration from registry", True)
		End If

		' Check if CDO profile info is created
		If Not IsEmpty(bstrProfileInfo) Then

			' Create CDO session
			Err.Clear
			On Error Resume Next
			Set objSession = Server.CreateObject("MAPI.Session")
			If Not objSession Is Nothing Then

				' Logon with anonymous CDO profile
				Err.Clear
				On Error Resume Next
				objSession.Logon "", "", False, True, 0, True, bstrProfileInfo

				' Check for possible error
				If Err.Number = 0 Then

					' Set application and impersonation
					Set Application("CDOAnonSession") = objSession
					Application("hImp") = objRenderApp.ImpID

					' We need to force the store to open before anonymous access will work
					Set objStores = objSession.InfoStores
					For intCounter = 1 To objStores.Count
						Set objStore = objStores.Item(intCounter)
						lMask = objStore.Fields.Item(CdoPR_STORE_SUPPORT_MASK) 
						If lMask And CdoPR_STORE_PUBLIC_FOLDERS Then
							Exit For
						End If
					Next
				Else

					' Error logon anonymously
					Call DebugAssert("Error logging on anonymously", True)
				End If

				' Get anonymous session timeout value
				intTimeout = objRenderApp.ConfigParameter("AnonymousSessionTimeout")

				' Check if value is set
				If intTimeout = 0 Then

					' Set timeout of session to 10 minutes
					intTimeout = 10
				End If
				Session.Timeout = intTimeout
			Else

				' Error creating CDO session
				Call DebugAssert("Error creating CDO session", True)
			End If
		Else

			' Error creating CDO profile
			Call DebugAssert("Error creating CDO profile", False)
		End If
	Else

		' Error creating render application
		Call DebugAssert("Error creating RenderApp", False)
	End If

	' Destroy objects
	Set objStore = Nothing
End Sub

'============================
' DebugAssert
'
' Helper function to pull out error details
'============================

Function DebugAssert(bstrContext, blnErrChkFlag)

	' Check if error check flag is set
	If boolErrChkFlag = True Then

		' Check if error found
		If Err.Number <> 0 Then

			' Pull out error details
			Response.Write("Error: " & bstrContext & " : " & Err.Number & ": " & Err.Description & "<br>")

			'  Clear error object
			Err.Clear
		End If
	Else

		' Display error message
		Response.Write("Error: " & bstrContext & "<br>")
	End If
End Function
%>